import React, { useState } from "react";
import { StyleSheet, SafeAreaView, Text, TextInput, View } from "react-native";
import { Button} from 'native-base';
import { useTheme } from '@react-navigation/native';

function Name({navigation}) {
    const { colors } = useTheme();
    const [firstName, setFirstName] = useState('');
    const [lastName, setLastName] = useState('');

    function handleNext() {
        navigation.navigate("Email", {
            firstName: firstName,
            lastName: lastName
        })
    }

    function handleSignIn() {
        navigation.navigate("Login")
    }
    return (
        <SafeAreaView style={ [styles.screen, {flexDirection:"column"}] }>
            <Text style={ [styles.title, {color: colors.text}] }>Enter your name:</Text>
            <Text style={ [styles.subtitle, {color: colors.text}] }>Please enter your first name.</Text>
            <TextInput placeholder = "Purdue" style={ [styles.input, {color: colors.text}] } onChangeText={(firstName) => setFirstName(firstName)} />
            <Text style={ [styles.subtitle, {color: colors.text}] }>Please enter your last name.</Text>
            <TextInput placeholder = "Pete" style={ [styles.input, {color: colors.text}] } onChangeText={(lastName) => setLastName(lastName)} />
            <View style={{flexDirection: "row"}}>
                <Button style={ styles.nextButton } onPress={handleNext} >
                    <Text style={ styles.nextText } >Next</Text>
                </Button>
            </View>
            <Text style={ [styles.subtitle, {color: colors.text}] }>If you already have an account, please sign in.</Text>
            <View style={{flexDirection: "row"}}>
                <Button style={ styles.nextButton } onPress={handleSignIn} >
                    <Text style={ styles.nextText } >Sign In</Text>
                </Button>
            </View>
        </SafeAreaView>
    );
}

const styles = StyleSheet.create({
    screen:{
        marginTop: "20%",
        paddingLeft: "5%",
        paddingRight: "5%",
        paddingBottom: "30%",
        marginLeft: "10%",
        marginRight: "10%"
    },
    title: {
        fontSize: 25,
        fontWeight: "bold",
        marginTop: "10%",
        paddingBottom: "20%",
        textAlign:"left"
    },
    subtitle: {
        fontSize: 16,
        textAlign:"left",
        fontWeight: "bold",
        color: '#5c5a55'
    },
    input: {
        width: "100%",
        height: 40,
        borderBottomWidth: 1
    },
    nextButton: {
        width: '100%',
        justifyContent: 'center',
        backgroundColor: "#d4911c",
        borderRadius: 10,
        alignItems: "center",
        marginBottom: 10,
        marginTop: 50
    },
    nextText: {
        fontSize: 16,
        fontWeight: "bold",
        color: "white"
    },
});

export default Name;
